Module predicates

Module predicates 

Predicates for strings.

Structs

Ascii
Checks if the string is valid ASCII.
Contains
Checks if the string contains the specified string S.
ContainsChar
Checks if the string contains the specified character C.
EndsWith
Checks if the string ends with the specified suffix S.
EndsWithChar
Checks if the string ends with the specified character C.
StartsWith
Checks if the string starts with the specified prefix P.
StartsWithChar
Checks if the string starts with the specified character C.
Trimmed
Checks if the string is trimmed.
TrimmedEnd
Checks if the string is trimmed at the end.
TrimmedStart
Checks if the string is trimmed at the start.

Constants

ASCII
The str::ascii literal.
ASCII_MESSAGE
The ascii string message.
CONTAINS
The str::contains literal.
ENDS_WITH
The str::ends_with literal.
STARTS_WITH
The str::starts_with literal.
TRIMMED
The str::trimmed literal.
TRIMMED_END
The str::trimmed_end literal.
TRIMMED_END_MESSAGE
The string trimmed at the end message.
TRIMMED_MESSAGE
The trimmed string message.
TRIMMED_START
The str::trimmed_start literal.
TRIMMED_START_MESSAGE
The string trimmed at the start message.