Module prelude

Module prelude 

The refining-str prelude.

Structs

Ascii
Checks if the string is valid ASCII.
BytesAll
Checks whether all bytes of the string satisfy the given predicate.
BytesAny
Checks whether any bytes of the string satisfy the given predicate.
CharsAll
Checks whether all chars of the string satisfy the given predicate.
CharsAny
Checks whether any chars of the string satisfy the given predicate.
Contains
Checks if the string contains the specified string S.
ContainsChar
Checks if the string contains the specified character C.
EndsWith
Checks if the string ends with the specified suffix S.
EndsWithChar
Checks if the string ends with the specified character C.
StartsWith
Checks if the string starts with the specified prefix P.
StartsWithChar
Checks if the string starts with the specified character C.
Trimmed
Checks if the string is trimmed.
TrimmedEnd
Checks if the string is trimmed at the end.
TrimmedStart
Checks if the string is trimmed at the start.